@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 use Path::Tiny qw( path );
 use Path::Tiny::Rule;
@@ -32,7 +32,7 @@ sub _maybe_write_file {
 
     return if -e $file;
 
-    file($file)->spew($content);
+    path($file)->spew_utf8($content);
 
     return;
 }
@@ -157,7 +157,7 @@ Dist::Zilla::Plugin::DROLSKY::PerlLinterConfigFiles - Creates default perltidyrc
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =for Pod::Coverage .*
 
